==> gatsby-source-notion-contents-1.1.0.tgz: package/gatsby-node.js <==
"use strict";

const Notion = require('get-notion-contents').default;

const formatUid = uid => {
  if (uid.indexOf('-') === -1) {
    return `${uid.slice(0, 8)}-${uid.slice(8, 12)}-${uid.slice(12, 16)}-${uid.slice(16, 20)}-${uid.slice(20)}`;
  }

  return uid;
};

const getSources = async ({
  actions: {
    createNode
  },
  createContentDigest
}, options) => {
  var _ref;

  const notion = new Notion(options === null || options === void 0 ? void 0 : options.token, {
    prefix: options === null || options === void 0 ? void 0 : options.prefix,
    removeStyle: (_ref = options === null || options === void 0 ? void 0 : options.removeStyle) !== null && _ref !== void 0 ? _ref : false
  });
  const hydratedIds = ((options === null || options === void 0 ? void 0 : options.ids) || []).map(formatUid);
  const pageIds = (await notion.getPageIds()).concat((options === null || options === void 0 ? void 0 : options.ids) || []);
  const pages = await Promise.all(pageIds.map(async id => {
    const page = await notion.getPageById(id);
    return {
      id,
      page
    };
  }));
  pages.forEach(({
    id,
    page: {
      type,
      titleString: description,
      title,
      content,
      resource = ''
    }
  }) => {
    const page = title + content + resource;
    const node = {
      id,
      parent: null,
      children: [],
      contentType: type,
      internal: {
        type: 'NotionContent',
        mediaType: 'text/html',
        content: page,
        contentDigest: createContentDigest(page),
        description
      }
    };
    createNode(node);
  });
};

exports.sourceNodes = getSources;

==> gatsby-source-notion-contents-1.1.1.tgz: package/gatsby-node.js <==
"use strict";

const Notion = require('get-notion-contents').default;

const formatUid = uid => {
  if (uid.indexOf('-') === -1) {
    return `${uid.slice(0, 8)}-${uid.slice(8, 12)}-${uid.slice(12, 16)}-${uid.slice(16, 20)}-${uid.slice(20)}`;
  }

  return uid;
};

const getSources = async ({
  actions: {
    createNode
  },
  createContentDigest
}, options) => {
  var _options$removeStyle;

  const notion = new Notion(options === null || options === void 0 ? void 0 : options.token, {
    prefix: options === null || options === void 0 ? void 0 : options.prefix,
    removeStyle: (_options$removeStyle = options === null || options === void 0 ? void 0 : options.removeStyle) !== null && _options$removeStyle !== void 0 ? _options$removeStyle : false
  });
  const hydratedIds = ((options === null || options === void 0 ? void 0 : options.ids) || []).map(formatUid);
  const pageIds = (await notion.getPageIds()).concat((options === null || options === void 0 ? void 0 : options.ids) || []);
  const pages = await Promise.all(pageIds.map(async id => {
    const page = await notion.getPageById(id);
    return {
      id,
      page
    };
  }));
  pages.forEach(({
    id,
    page: {
      type,
      titleString: description,
      title,
      content,
      resource = ''
    }
  }) => {
    const page = title + content + resource;
    const node = {
      id,
      parent: null,
      children: [],
      contentType: type,
      internal: {
        type: 'NotionContent',
        mediaType: 'text/html',
        content: page,
        contentDigest: createContentDigest(page),
        description
      }
    };
    createNode(node);
  });
};

exports.sourceNodes = getSources;
